Calculates committor of a markovchain object with respect to set A, B
Source:R/probabilistic.R
committorAB.RdReturns the probability of hitting states rom set A before set B with different initial states
R/probabilistic.R
committorAB.RdReturns the probability of hitting states rom set A before set B with different initial states