| is.lumpable | R Documentation |
Verifies the strong lumpability condition with respect to a partition of the state space. For every pair of macro-states, all micro-states in the same source macro-state must have the same total probability of moving to the destination macro-state.
is.lumpable(object, partition, tol = 1e-10)
## S4 method for signature 'markovchain'
is.lumpable(object, partition, tol = 1e-10)
object |
A |
partition |
A named list of character vectors defining macro-states. |
tol |
Non-negative numerical tolerance for equality checks. |
A logical value.
Kemeny, J. G. and Snell, J. L. (1960). Finite Markov Chains.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.