Check if a Markov chain is stochastically monotone
Source:R/probabilistic.R
is.stochasticallyMonotone.RdVerifies if the transition matrix of the Markov chain is stochastically monotone.
R/probabilistic.R
is.stochasticallyMonotone.RdVerifies if the transition matrix of the Markov chain is stochastically monotone.