Learn R Programming

markovchain (version 0.6.9.10)

kullback: Example from Kullback and Kupperman Tests for Contingency Tables

Description

A list of two matrices representing raw transitions between two states

Usage

data(kullback)

Arguments

Format

A list containing two 6x6 non - negative integer matrices