This function provides a prediction of states for a higher order multivariate markovchain object
Value
The function returns a matrix of size s X t displaying t predicted states in each row coressponding to every categorical sequence.
This function provides a prediction of states for a higher order multivariate markovchain object
The function returns a matrix of size s X t displaying t predicted states in each row coressponding to every categorical sequence.