| autoLump | R Documentation |
Finds an approximate partition by clustering the leading right eigenvectors of the transition matrix, then returns the forced lumping over that partition. This is a heuristic for approximate lumping/metastable aggregation, not a proof of exact lumpability.
autoLump(object, k)
## S4 method for signature 'markovchain'
autoLump(object, k)
object |
A |
k |
Number of macro-states to discover. |
A list with partition and lumped_chain.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.