Learn R Programming

markovchain (version 0.6.9.10)

ctmc-class: Class "ctmc"

Description

The S4 class that describes ctmc (continuous time Markov chain) objects.

Arguments

Objects from the Class

Objects can be created by calls of the form new("ctmc", states, byrow, generator, ...).

Slots

states:

Name of the states. Must be the same of colnames and rownames of the generator matrix

byrow:

Binary flag.

generator:

Square generator matrix

name:

Optional character name of the Markov chain

Methods

dim

signature(x = "ctmc"): method to get the size

initialize

signature(.Object = "ctmc"): initialize method

states

signature(object = "ctmc"): states method.

steadyStates

signature(object = "ctmc"): method to get the steady state vector.

plot

signature(x = "ctmc", y = "missing"): plot method for ctmc objects

Warning

Validation method is used to assess whether either columns or rows totals to zero. Rounding is used up to 5th decimal. If state names are not properly defined for a generator matrix, coercing to ctmc object leads to overriding states name with artificial "s1", "s2", ... sequence

References

Introduction to Stochastic Processes with Applications in the Biosciences (2013), David F. Anderson, University of Wisconsin at Madison

See Also

generatorToTransitionMatrix,rctmc

Examples

Run this code
# NOT RUN {
energyStates <- c("sigma", "sigma_star")
byRow <- TRUE
gen <- matrix(data = c(-3, 3,
                       1, -1), nrow = 2,
              byrow = byRow, dimnames = list(energyStates, energyStates))
molecularCTMC <- new("ctmc", states = energyStates, 
                 byrow = byRow, generator = gen, 
                 name = "Molecular Transition Model")

steadyStates(molecularCTMC)
# }
# NOT RUN {
plot(molecularCTMC)
# }

Run the code above in your browser using DataLab