Verifies the strong lumpability condition with respect to a partition of the state space. For every pair of macro-states, all micro-states in the same source macro-state must have the same total probability of moving to the destination macro-state.
Usage
is.lumpable(object, partition, tol = 1e-10)
# S4 method for class 'markovchain'
is.lumpable(object, partition, tol = 1e-10)