| lump | R Documentation |
Coarsens a Markov chain to a reduced state space. By default the
function requires exact lumpability. With force = TRUE, it performs an
approximate aggregation using stationary weights when available and arithmetic
averages for macro-states with zero stationary mass.
lump(object, partition, force = FALSE)
## S4 method for signature 'markovchain'
lump(object, partition, force = FALSE)
object |
A |
partition |
A named list of character vectors defining macro-states. |
force |
If |
A markovchain object on the macro-state space.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.