Coarsens a Markov chain to a reduced state space. By default the
function requires exact lumpability. With force = TRUE, it performs an
approximate aggregation using stationary weights when available and arithmetic
averages for macro-states with zero stationary mass.
Usage
lump(object, partition, force = FALSE)
# S4 method for class 'markovchain'
lump(object, partition, force = FALSE)