Objects from the Class
Objects can be created by calls of the form new("markovchain", states, byrow, transitionMatrix, ...).Warning
Validation method is used to assess whether either columns or rows totals to one. Rounding is used up to 5th decimal