Learn R Programming

markovchain (version 0.0.2)

markovchainList-class: Class "markovchainList"

Description

A class to handle non - homogeneous markov chains

Arguments

Objects from the Class

Objects can be created by calls of the form new("markovchainList", ...). Each item in the list is a markovchain object.

Methods

No methods defined with class "markovchainList" in the signature.

References

Sheldon Ross

See Also

markovchain

Examples

Run this code
showClass("markovchainList")

Run the code above in your browser using DataLab