markovchainList-class: Class "markovchainList"
Description
A class to handle non - homogeneous markov chainsObjects from the Class
Objects can be created by calls of the form new("markovchainList", ...).
Each item in the list is a markovchain object.Methods
No methods defined with class "markovchainList" in the signature.